# Changelog

## [Unreleased]

- TODO

## [2.0] - 2023-01-09

### Added

- lint && test github workflow

### Changed

- upgrade pyopenssl usage due to https://github.com/pyca/cryptography/issues/6456

### Fixed

- use 'with' for resource-allocating operations

## [1.2] - 2020-03-25

### Added

- Support JWT auth in push notifications
